@@ -21,16 +21,16 @@ sub request
     # check proxy
     if (defined $proxy)
     {
-	return new HTTP::Response &HTTP::Status::RC_BAD_REQUEST,
-				  'You can not proxy through the filesystem';
+	return HTTP::Response->new( &HTTP::Status::RC_BAD_REQUEST,
+				  'You can not proxy through the filesystem');
     }
 
     # check method
     my $method = $request->method;
     unless ($method eq 'GET' || $method eq 'HEAD') {
-	return new HTTP::Response &HTTP::Status::RC_BAD_REQUEST,
+	return HTTP::Response->new( &HTTP::Status::RC_BAD_REQUEST,
 				  'Library does not allow method ' .
-				  "$method for 'file:' URLs";
+				  "$method for 'file:' URLs");
     }
 
     # check url
@@ -38,8 +38,8 @@ sub request
 
     my $scheme = $url->scheme;
     if ($scheme ne 'file') {
-	return new HTTP::Response &HTTP::Status::RC_INTERNAL_SERVER_ERROR,
-			   "LWP::Protocol::file::request called for '$scheme'";
+	return HTTP::Response->new( &HTTP::Status::RC_INTERNAL_SERVER_ERROR,
+			   "LWP::Protocol::file::request called for '$scheme'");
     }
 
     # URL OK, look at file
@@ -47,12 +47,12 @@ sub request
 
     # test file exists and is readable
     unless (-e $path) {
-	return new HTTP::Response &HTTP::Status::RC_NOT_FOUND,
-				  "File `$path' does not exist";
+	return HTTP::Response->new( &HTTP::Status::RC_NOT_FOUND,
+				  "File `$path' does not exist");
     }
     unless (-r _) {
-	return new HTTP::Response &HTTP::Status::RC_FORBIDDEN,
-				  'User does not have read permission';
+	return HTTP::Response->new( &HTTP::Status::RC_FORBIDDEN,
+				  'User does not have read permission');
     }
 
     # looks like file exists
@@ -67,13 +67,13 @@ sub request
     if (defined $ims) {
 	my $time = HTTP::Date::str2time($ims);
 	if (defined $time and $time >= $mtime) {
-	    return new HTTP::Response &HTTP::Status::RC_NOT_MODIFIED,
-				      "$method $path";
+	    return HTTP::Response->new( &HTTP::Status::RC_NOT_MODIFIED,
+				      "$method $path");
 	}
     }
 
     # Ok, should be an OK response by now...
-    my $response = new HTTP::Response &HTTP::Status::RC_OK;
+    my $response = HTTP::Response->new( &HTTP::Status::RC_OK );
 
     # fill in response headers
     $response->header('Last-Modified', HTTP::Date::time2str($mtime));
@@ -81,8 +81,8 @@ sub request
     if (-d _) {         # If the path is a directory, process it
 	# generate the HTML for directory
 	opendir(D, $path) or
-	   return new HTTP::Response &HTTP::Status::RC_INTERNAL_SERVER_ERROR,
-				     "Cannot read directory '$path': $!";
+	   return HTTP::Response->new( &HTTP::Status::RC_INTERNAL_SERVER_ERROR,
+				     "Cannot read directory '$path': $!");
 	my(@files) = sort readdir(D);
 	closedir(D);
 
